@@ -3,7 +3,7 @@ BEGIN {
   $Geo::Routing::Driver::OSRM::Query::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $Geo::Routing::Driver::OSRM::Query::VERSION = '0.09';
+  $Geo::Routing::Driver::OSRM::Query::VERSION = '0.10';
 }
 use Any::Moose;
 use warnings FATAL => "all";
@@ -11,11 +11,11 @@ use warnings FATAL => "all";
 with 'Geo::Routing::Role::Query';
 
 sub query_string {
-    my ($self) = @_;
+    my ($self, $method) = @_;
 
     my @atoms = qw(from_latitude from_longitude to_latitude to_longitude);
 
-    my $query_string = '&output=json&' . join '&', map { $self->$_ } @atoms;
+    my $query_string = "&output=$method&instructions=true&geometry=false&" . join '&', map { $self->$_ } @atoms;
 
     return $query_string;
 }
