@@ -3,7 +3,7 @@ BEGIN {
   $Geo::Routing::Role::Driver::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $Geo::Routing::Role::Driver::VERSION = '0.09';
+  $Geo::Routing::Role::Driver::VERSION = '0.10';
 }
 use Any::Moose '::Role';
 use warnings FATAL => "all";
@@ -21,9 +21,18 @@ has _mech => (
 sub _build__mech {
     my ($self) = @_;
 
-    WWW::Mechanize->new(
+    my $mech = WWW::Mechanize->new(
         user_agent => __PACKAGE__,
+        proxy => '',
     );
+
+    $mech->default_header(
+        'Accept-Encoding' => "gzip,deflate",
+        'Keep-Alive' => "300",
+        'Connection' => "keep-alive",
+    );
+
+    return $mech;
 }
 
 1;
